/*
 * Copyright (c) 2021-2023 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include <jeffpc/error.h>

#include "hamlib-impl.h"

void hamlib_set_quirks(struct hrig *rig, uint32_t model)
{
	if (model == RIG_MODEL_NETRIGCTL) {
		rig->quirks.no_txpower = true;
		cmn_err(CE_WARN, "Hamlib 4.3.1 and older has buggy netrigctl");
		cmn_err(CE_WARN, "Disabling power announcements");
	} else if (model == RIG_MODEL_KX2) {
		rig->quirks.no_txpower = true;
		cmn_err(CE_WARN, "Hamlib 4.5.5 and older has buggy KX2 backend");
		cmn_err(CE_WARN, "Disabling power announcements");
	}
}
